voca package
============

Subpackages
-----------

.. toctree::

    voca.plugins

Submodules
----------

voca.app module
---------------

.. automodule:: voca.app
    :members:
    :undoc-members:
    :show-inheritance:

voca.caster\_adapter module
---------------------------

.. automodule:: voca.caster_adapter
    :members:
    :undoc-members:
    :show-inheritance:

voca.cli module
---------------

.. automodule:: voca.cli
    :members:
    :undoc-members:
    :show-inheritance:

voca.config module
------------------

.. automodule:: voca.config
    :members:
    :undoc-members:
    :show-inheritance:

voca.context module
-------------------

.. automodule:: voca.context
    :members:
    :undoc-members:
    :show-inheritance:

voca.listen module
------------------

.. automodule:: voca.listen
    :members:
    :undoc-members:
    :show-inheritance:

voca.log module
---------------

.. automodule:: voca.log
    :members:
    :undoc-members:
    :show-inheritance:

voca.manager module
-------------------

.. automodule:: voca.manager
    :members:
    :undoc-members:
    :show-inheritance:

voca.mic module
---------------

.. automodule:: voca.mic
    :members:
    :undoc-members:
    :show-inheritance:

voca.parsing module
-------------------

.. automodule:: voca.parsing
    :members:
    :undoc-members:
    :show-inheritance:

voca.patching module
--------------------

.. automodule:: voca.patching
    :members:
    :undoc-members:
    :show-inheritance:

voca.platforms module
---------------------

.. automodule:: voca.platforms
    :members:
    :undoc-members:
    :show-inheritance:

voca.streaming module
---------------------

.. automodule:: voca.streaming
    :members:
    :undoc-members:
    :show-inheritance:

voca.utils module
-----------------

.. automodule:: voca.utils
    :members:
    :undoc-members:
    :show-inheritance:

voca.worker module
------------------

.. automodule:: voca.worker
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: voca
    :members:
    :undoc-members:
    :show-inheritance:
